# Google Cloud Engine driver installation guide

## Requirements

-   A GCE credentials rc file

## Install

Please refer to the [Virtual environment][] documentation for
installation best practices. If not using a virtual environment, please
consider passing the widely recommended ['--user' flag][] when invoking
`pip`.

``` bash
$ pip install 'molecule_gce'
```

  [Virtual environment]: https://virtualenv.pypa.io/en/latest/
  ['--user' flag]: https://packaging.python.org/tutorials/installing-packages/#installing-to-the-user-site
